RuleCondition class

Constructors

RuleCondition({required String context, required String op, required Object value})
RuleCondition.fromMap(Map<String, dynamic> map)
factory

Properties

context → String
final
hashCode → int
The hash code for this object.
no setterinherited
op → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited